Crate souvenir_macros

Crate souvenir_macros 

souvenir_macros

This crate contains procedural macros for souvenir. This crate is not intended to be used directly.

Macros

id
Create an Id based on some literal input. All inputs are verified at compile time to ensure that the Id is valid.
prefix
Create a Prefix based on some literal input. All inputs are verified at compile time to ensure that the Prefix is valid.

Derive Macros

Identifiable
Automatically implement Identifiable.
Tagged
Automatically implement Tagged.